@@ -1,8 +1,8 @@
 from ruamel.yaml.parser import ParserError
 
 from forge_template.exception.exceptions import AccessDeniedException, ValidationException
-from forge_template.util.user_interface import UserInterface
-from forge_template.util.yaml_util import YAML_CONFIG_PATH, YAML_SECRETS_PATH
+from forge_template.paths import YAML_CONFIG_PATH, YAML_SECRETS_PATH
+from forge_template.user_interface import UserInterface
 
 
 def handle_file_not_found(e: FileNotFoundError) -> None:
