@@ -8,10 +8,11 @@ from databricks_api import DatabricksAPI
 from requests import HTTPError
 
 import forge_template.util.file_util as file_util
-import forge_template.util.log_utils as log_utils
+import forge_template.util.log_util as log_util
+from forge_template.handler.github_actions_handler import GithubActionsHandler
 from forge_template.handler.handler import FORBIDDEN_CODE, NOT_FOUND_CODE, BaseHandler
-from forge_template.util.paths import DATABRICKS_PATH, DATABRICKS_TEMPLATE_PATH, notebooks_to_copy
-from forge_template.util.yaml_util import YAML_CONFIG_PATH
+from forge_template.paths import DATABRICKS_PATH, DATABRICKS_TEMPLATE_PATH, notebooks_to_copy
+from forge_template.tool_info import ToolInfo
 
 CONFIG_PATH_PLACEHOLDER = "YAML_CONFIG_PATH_PLACEHOLDER"
 DEFAULT_SCOPE_ACCESS = "WRITE"
@@ -22,14 +23,17 @@ DBFS_DIRECTORY = "DBFS Directory"
 
 
 class DatabricksHandler(BaseHandler):
-    def __init__(self, name: str, config: Dict) -> None:
-        config = config[name]
+    def __init__(self, config: Dict, tool_info: ToolInfo) -> None:
+        self.name = tool_info.name
+        config = config[self.name]
         self.client = DatabricksAPI(host=config["host"], token=config["token"])
 
         self._dev_workspace = config["development"]
         self._prod_workspace = config["production"]
         self._dbfs_path = config["config_dbfs_path"]
 
+        self._config_output_path = tool_info.schema_info[0].output_path
+
         self.workspaces_to_create: List[str] = []
         self.groups_to_create: List[str] = []
         self.scopes_to_create: List[Dict[str, str]] = []
@@ -45,9 +49,11 @@ class DatabricksHandler(BaseHandler):
         self.added_users_to_group: Dict[str, List[str]] = {}
         self.added_groups_to_scope: Dict[str, List[str]] = {}
 
+        self.github_actions_handler = GithubActionsHandler(tool_info=tool_info)
+
         self.dbfs_config_path = ""
 
-        super().__init__(name=name, config=config)
+        super().__init__(config=config, tool_info=tool_info)
 
     def create_preview(self) -> None:
         self.check_dbfs_dir_to_add(self._dbfs_path)
@@ -56,14 +62,16 @@ class DatabricksHandler(BaseHandler):
         self.check_groups_to_add([self._dev_workspace["group"], self._prod_workspace["group"]])
 
     def print_preview(self):
-        log_utils.print_resource_to_add(self.workspaces_to_create, "Workspaces")
-        log_utils.print_resource_to_add(self.groups_to_create, "Groups")
-        log_utils.print_resource_to_add(list(map(lambda scope: scope["scope_name"], self.scopes_to_create)), "Scopes")
-        log_utils.print_resource_to_add(self.dbfs_dirs_to_create, "DBFS Directories")
+        log_util.print_resource_to_add(self.workspaces_to_create, "Workspaces")
+        log_util.print_resource_to_add(self.groups_to_create, "Groups")
+        log_util.print_resource_to_add(list(map(lambda scope: scope["scope_name"], self.scopes_to_create)), "Scopes")
+        log_util.print_resource_to_add(self.dbfs_dirs_to_create, "DBFS Directories")
         logging.info("")
-        log_utils.print_resources_to_update(self.users_to_add_to_group, "User", "Group")
-        log_utils.print_resources_to_update(self.secrets_to_add_to_scope, "Secret", "Scope")
-        log_utils.print_resources_to_update(self.groups_to_add_to_scope, "Group", "Scope")
+        log_util.print_resources_to_update(self.users_to_add_to_group, "User", "Group")
+        log_util.print_resources_to_update(self.secrets_to_add_to_scope, "Secret", "Scope")
+        log_util.print_resources_to_update(self.groups_to_add_to_scope, "Group", "Scope")
+        logging.info("")
+        self.github_actions_handler.print_preview()
 
     def setup(self):
         self.create_workspaces(self.workspaces_to_create)
@@ -73,6 +81,7 @@ class DatabricksHandler(BaseHandler):
         self.create_scopes(self.scopes_to_create)
         self.add_groups_to_scope(self.groups_to_add_to_scope)
         self.add_secrets_to_scope(self.secrets_to_add_to_scope)
+        self.github_actions_handler.run_setup()
 
     def rollback(self) -> None:
         if self.created_scopes:
@@ -109,7 +118,7 @@ class DatabricksHandler(BaseHandler):
     def upload_config(self) -> None:
         self.check_dbfs_dir_to_add(self._dbfs_path)
         self.create_dbfs_directories(self.dbfs_dirs_to_create)
-        self.copy_files_to_dbfs(self.dbfs_config_path, YAML_CONFIG_PATH)
+        self.copy_files_to_dbfs(self.dbfs_config_path, self._config_output_path)
 
     def check_groups_to_add(self, groups: List) -> None:
         """
@@ -124,7 +133,7 @@ class DatabricksHandler(BaseHandler):
             users = group["users"]
 
             if group_name in existing_groups:
-                log_utils.print_resource_already_exists(group_name, "Group")
+                log_util.print_resource_already_exists(group_name, "Group")
                 self.check_users_to_add(group_name, users, True)
             else:
                 self.check_users_to_add(group_name, users, False)
@@ -166,7 +175,7 @@ class DatabricksHandler(BaseHandler):
 
         scope_exists = False
         if scope_name in existing_scopes:
-            log_utils.print_resource_already_exists(scope_name, "Scope")
+            log_util.print_resource_already_exists(scope_name, "Scope")
             scope_exists = True
         else:
             self.scopes_to_create.append(
@@ -205,7 +214,7 @@ class DatabricksHandler(BaseHandler):
         """
         for workspace_path in workspace_paths:
             if self.does_path_exist(workspace_path, lambda client, path: client.workspace.list(path)):
-                log_utils.print_resource_already_exists(workspace_path, WORKSPACE)
+                log_util.print_resource_already_exists(workspace_path, WORKSPACE)
             else:
                 self.workspaces_to_create.append(workspace_path)
 
@@ -217,7 +226,7 @@ class DatabricksHandler(BaseHandler):
             dbfs_path: Path to check
         """
         if self.does_path_exist(dbfs_path, lambda client, path: client.dbfs.list(path)):
-            log_utils.print_resource_already_exists(dbfs_path, DBFS_DIRECTORY)
+            log_util.print_resource_already_exists(dbfs_path, DBFS_DIRECTORY)
         else:
             self.dbfs_dirs_to_create.append(dbfs_path)
 
@@ -233,7 +242,7 @@ class DatabricksHandler(BaseHandler):
         for name in group_names:
             self.client.groups.create_group(name)
             self.created_groups.append(name)
-            log_utils.print_success_created(entity_name=name, entity_type="Group")
+            log_util.print_success_created(entity_name=name, entity_type="Group")
 
     def add_users_to_group(self, group_to_users: Dict[str, List[str]]):
         """
@@ -248,7 +257,7 @@ class DatabricksHandler(BaseHandler):
                 if group_name not in self.added_users_to_group:
                     self.added_users_to_group[group_name] = []
                 self.added_users_to_group[group_name].append(name)
-                log_utils.print_success_added(group_name, "Group", name, "User")
+                log_util.print_success_added(group_name, "Group", name, "User")
 
     def create_scopes(self, scopes: List[Dict]) -> None:
         """
@@ -263,7 +272,7 @@ class DatabricksHandler(BaseHandler):
             )
 
             self.created_scopes.append(scope["scope_name"])
-            log_utils.print_success_created(scope["scope_name"], "Scope")
+            log_util.print_success_created(scope["scope_name"], "Scope")
 
     def add_secrets_to_scope(self, scope_to_secrets: Dict[str, List[Dict]]) -> None:
         """
@@ -280,7 +289,7 @@ class DatabricksHandler(BaseHandler):
         for scope, secrets in scope_to_secrets.items():
             for secret in secrets:
                 self.client.secret.put_secret(scope, secret["key"], secret["string_value"])
-                log_utils.print_success_added(scope, "Scope", secret["key"], "Token")
+                log_util.print_success_added(scope, "Scope", secret["key"], "Token")
 
     # TODO: Handling of Databricks account that isn't premium
     def add_groups_to_scope(self, scope_to_group: Dict[str, List[str]]) -> None:
@@ -297,7 +306,7 @@ class DatabricksHandler(BaseHandler):
                     if scope not in self.added_groups_to_scope:
                         self.added_groups_to_scope[scope] = []
                     self.added_groups_to_scope[scope].append(group)
-                    log_utils.print_success_added(scope, "Scope", group, "Group")
+                    log_util.print_success_added(scope, "Scope", group, "Group")
                 except HTTPError as e:
                     if e.response.status_code == FORBIDDEN_CODE:
                         logging.warning(f"Account doesn't support ACL.")
@@ -312,7 +321,7 @@ class DatabricksHandler(BaseHandler):
             workspace_paths: Paths to add workspace to in Databricks
         """
         file_util.copy_folders(DATABRICKS_TEMPLATE_PATH, DATABRICKS_PATH, ignore=["*template*", "__init__.py"])
-        dbfs_location = f"/dbfs/{self.dbfs_config_path[1:]}/{YAML_CONFIG_PATH}"
+        dbfs_location = f"/dbfs/{self.dbfs_config_path[1:]}/{self._config_output_path}"
         file_util.copy_files_and_replace_placeholders(notebooks_to_copy, CONFIG_PATH_PLACEHOLDER, dbfs_location)
         for path in workspace_paths:
             self.create_workspace(path)
@@ -334,7 +343,7 @@ class DatabricksHandler(BaseHandler):
 
     def create_workspace_directory(self, directory_path: str) -> None:
         self.client.workspace.mkdirs(directory_path)
-        log_utils.print_success_created(directory_path, WORKSPACE_DIRECTORY)
+        log_util.print_success_created(directory_path, WORKSPACE_DIRECTORY)
 
     def copy_notebooks_to_workspace(self, workspace_path: str) -> None:
         notebook_paths = glob.glob(os.path.join(DATABRICKS_PATH, "**", "*.py"))
@@ -346,14 +355,14 @@ class DatabricksHandler(BaseHandler):
 
             notebook_name = os.path.basename(path)
             dir_name = os.path.dirname(upload_path)
-            log_utils.print_success_added(dir_name, WORKSPACE_DIRECTORY, notebook_name, "Notebook")
+            log_util.print_success_added(dir_name, WORKSPACE_DIRECTORY, notebook_name, "Notebook")
 
     def copy_files_to_dbfs(self, dbfs_path: str, local_path: str) -> None:
         file_name = os.path.basename(local_path)
         content = file_util.get_base64_encoded_content(local_path)
         upload_path = file_util.get_absolute_posix_path(dbfs_path, file_name)
         self.client.dbfs.put(upload_path, contents=content)
-        log_utils.print_success_added(dbfs_path, DBFS_DIRECTORY, file_name, "File")
+        log_util.print_success_added(dbfs_path, DBFS_DIRECTORY, file_name, "File")
 
     def create_dbfs_directories(self, directory_paths: List[str]) -> None:
         """
@@ -365,8 +374,8 @@ class DatabricksHandler(BaseHandler):
         for path in directory_paths:
             self.client.dbfs.mkdirs(path)
             self.created_dbfs_dirs.append(path)
-            log_utils.print_success_created(path, DBFS_DIRECTORY)
-            self.copy_files_to_dbfs(path, YAML_CONFIG_PATH)
+            log_util.print_success_created(path, DBFS_DIRECTORY)
+            self.copy_files_to_dbfs(path, self._config_output_path)
 
     def remove_groups(self, groups: List) -> None:
         self.remove_entities(
@@ -436,7 +445,7 @@ class DatabricksHandler(BaseHandler):
         entities = get_existing(entities)
         for entity in entities:
             remove(self.client, entity)
-            log_utils.print_success_deleted(entity, entity_type)
+            log_util.print_success_deleted(entity, entity_type)
 
     def remove_sub_entity_from_entity(
         self,
@@ -452,7 +461,7 @@ class DatabricksHandler(BaseHandler):
             sub_entities = get_exisiting_sub_entities(entity, entity_to_sub[entity])
             for sub_entity in sub_entities:
                 remover(self.client, entity, sub_entity)
-                log_utils.print_success_removed(sub_entity, entity, sub_entity_type, entity_type)
+                log_util.print_success_removed(sub_entity, entity, sub_entity_type, entity_type)
 
     def remove_paths(
         self,
@@ -464,7 +473,7 @@ class DatabricksHandler(BaseHandler):
         for path in paths:
             if self.does_path_exist(path, existence_checker):
                 delete_method(self.client, path)
-                log_utils.print_success_deleted(path, path_type)
+                log_util.print_success_deleted(path, path_type)
 
     def does_path_exist(self, dir_path: str, check_function: Callable) -> bool:
         """
